<%
/*******************************************************************************
 * Author: Geoff Moes and Robert Sheldon
 * Project: Begining MySQL - Chapter 18
 * Module: edit.jsp
 * Date: 12/10/04
 *
 * Description:
 *
 *  This page lists the individual record. It is called from the main page.
 *  If the page is called with an "add" command, it creates a blank record 
 *  and populates it with default values. If it is called with an "edit" 
 *  command, it displays an existing record.
 *
 *******************************************************************************/
%>



<%@ page import="java.sql.*,
java.text.SimpleDateFormat,
java.lang.Integer" %>

<%
// Initialize variables with parameters retrieved from the form
String command = request.getParameter("command");
String transactionIdString = request.getParameter("transaction_id");
String dateDueString = request.getParameter("date_due");
String orderIdString = request.getParameter("order_id");
String dvdIdString = request.getParameter("dvd_id");
String dateOutString = request.getParameter("date_out");
String dateInString = request.getParameter("date_in");

// Initialize variables with default values
java.util.Date dateDue = null;
int transId = -1;
int orderId = -1;
int dvdId = -1;
java.util.Date dateOut = null;
java.util.Date dateIn = null;

String error = "";

SimpleDateFormat dateFormat = new SimpleDateFormat("MM-dd-yyyy");

// Declare variables for database-related operations
Connection connection;
Statement statement;


// Wrap database-access code in try/catch block to handle errors
try
{
// Create a DriverManager object to connect to the database
   Class.forName("com.mysql.jdbc.Driver").newInstance();
   connection = DriverManager.getConnection("jdbc:mysql://localhost/DVDRentals",
                                            "mysqlapp",
                                            "pw1");


// Process the save and savenew commands
   if("save".equals(command) || "savenew".equals(command))
   {
// Check for missing parameters and reformat the dates for MySQL
      if(transactionIdString != null)
         transId = Integer.valueOf(transactionIdString).intValue();

      if(orderIdString != null)
         orderId = Integer.valueOf(orderIdString).intValue();

      if(orderId == -1)
         error += "Please select an \"Order\"<br>";

      if(dvdIdString != null)
         dvdId = Integer.valueOf(dvdIdString).intValue();

      if(dvdId == -1)
         error += "Please select a \"DVD\"<br>";

      if((dateDueString != null) && (dateDueString.length() > 0))
         dateDue = dateFormat.parse(dateDueString);
      else
         error += "Please enter a \"Date Due\"<br>";

      if((dateOutString != null) && (dateOutString.length() > 0))
         dateOut = dateFormat.parse(dateOutString);
      else
         error += "Please enter a \"Date Out\"<br>";

      if((dateInString != null) && (dateInString.length() > 0))
         dateIn = dateFormat.parse(dateInString);


      if(error.length() == 0)
      {
         if("save".equals(command))
         {
// Run the update in update.jsp
%>
            <%@ include file="update.jsp" %>
<%
         }
         else
         {
// Run the insert in insert.jsp
%>
            <%@ include file="insert.jsp" %>
<%
         }

// Redirect the application to the listing page
         response.sendRedirect("index.jsp");
      }
   }


   else
   {
// If it is a new record, initialize the variables to default values
      if("add".equals(command))
      {
         transId = 0;
         orderId = 0;
         dvdId = 0;
         dateOutString = dateFormat.format(new java.util.Date());
         dateDueString = dateFormat.format(new Date((new java.util.Date()).getTime() + 3L*24L*60L*60000L));
         dateInString = "";
      }


      else
      {
// If it is an existing record, read from database

         if(transactionIdString != null)
         {

// Build query from transactionId value passed down from form
            transId = Integer.valueOf(transactionIdString).intValue();

            String selectSql = "SELECT " +
                               "OrderID, " +
                               "DVDID, " +
                               "DateOut, " +
                               "DateDue, " +
                               "DateIn " +
                               "FROM Transactions " +
                               "WHERE TransID = ?";
// Execute query
            PreparedStatement preparedStatement = connection.prepareStatement(selectSql);

            preparedStatement.setInt(1, transId);

            ResultSet rs = preparedStatement.executeQuery();

// Populate the variables for display into the form
            if(rs.next())
            {
               orderId = rs.getInt("OrderID");
               dvdId = rs.getInt("DVDID");
               dateOut = (java.util.Date) rs.getDate("DateOut");
               dateDue = (java.util.Date) rs.getDate("DateDue");
               dateIn = (java.util.Date) rs.getDate("DateIn");

// Reformat the dates into a more readable form
               if(dateOut != null)
                  dateOutString = dateFormat.format(dateOut);
               else
                  dateOutString = "";

               if(dateDue != null)
                  dateDueString = dateFormat.format(dateDue);
               else
                  dateDueString = "";

               if(dateIn != null)
                  dateInString = dateFormat.format(dateIn);
               else
                  dateInString = "";
            }

// Close the database objects
            rs.close();
            preparedStatement.close();
         }
      }
   }
%>


<html>
<head>
   <title>DVD - Listing</title>
   <link rel="stylesheet" href="dvdstyle.css" type="text/css">
   <script language="JavaScript" src="dvdrentals.js"></script>
</head>

<body>

<form name="mainForm" method="post" action="edit.jsp">
<input type="hidden" name="command" value="view">
<input type="hidden" name="transaction_id" value="<%=transId%>">

<p></p>

<table cellspacing="0" cellPadding="0" width="619" border="0">
<tr>
   <td>
      <table height="20" cellspacing="0" cellPadding="0" width="619" border="0">
      <tr align=left>
         <td valign="bottom" width="400" class="title">
            DVD Transaction
         </td>
         <td align="right" width="219" class="title">&nbsp;</td>
      </tr>
      </table>
      <br>
      <%if(error.length() > 0){%>
      <table cellspacing="2" cellPadding="2" width="619" border="0">
      <tr>
         <td width="619" class="error"><%=error%></td>
      </tr>
      </table>
      <%}%>


      <table cellspacing="2" cellPadding="2" width="619" border="0">
      <tr>
         <td width="250" class="heading">Order</td>
         <td class="item">
            <select name="order_id">
               <option value="-1">Select Order</option>
<%
// Retrieve data to populate drop-down list
   String selectSql = "SELECT " +
                      "Orders.OrderID, " +
                      "Orders.CustID, " +
                      "Customers.CustFN, " +
                      "Customers.CustLN " +
                      "FROM Orders, Customers " +
                      "WHERE " +
                      "Customers.CustID = Orders.CustID " +
                      "ORDER BY Orders.OrderID DESC, Customers.CustLN ASC, " +
                      "Customers.CustFN ASC";

// Execute the query
   statement = connection.createStatement();
   ResultSet rs = statement.executeQuery(selectSql);

// Loop through the results
   while(rs.next())
   {
// Assign returned value to the variables
      int orderId1 = rs.getInt("OrderID");
      String custFirstName = rs.getString("CustFN");
      String custLastName = rs.getString("CustLN");

// Format the data for display
      String customerName = "";

      if(custFirstName != null)
         customerName += custFirstName + " ";

      if(custLastName != null)
         customerName += custLastName;

// If the order id matches the existing value, mark it as selected
      if(orderId1 != orderId)
      {
%>
               <option value="<%=orderId1%>"><%=orderId1%> - <%=customerName%></option>
<%
      }
      else
      {
%>
               <option selected value="<%=orderId1%>"><%=orderId1%> - <%=customerName%></option>
<%
      }
   }

// Close database objects
   rs.close();
   statement.close();
%>
            </select>
         </td>
      </tr>


      <tr>
         <td class="heading">DVD</td>
         <td class="item">
            <select name="dvd_id">
               <option value="-1">Select DVD</option>
<%
// Retrieve data to populate the drop-down list
    selectSql = "SELECT DVDID, DVDName FROM DVDs ORDER BY DVDName";

    statement = connection.createStatement();
    rs = statement.executeQuery(selectSql);

    while(rs.next())
    {
       int dvdId1 = rs.getInt("DVDID");
       String dvdName = rs.getString("DVDName");

       if(dvdName == null) dvdName = "";

       if(dvdId1 != dvdId)
       {
%>
               <option value="<%=dvdId1%>"><%=dvdName%></option>
<%
       }
       else
       {
%>
               <option selected value="<%=dvdId1%>"><%=dvdName%></option>
<%
       }
    }

// Close the database objects
    rs.close();
    statement.close();
%>
            </select>
         </td>
      </tr>


      <tr>
         <td class="heading">Date Out</td>
         <td class="item">
            <input type="text" name="date_out" value="<%=dateOutString%>" size="50">
         </td>
      </tr>
      <tr>
         <td class="heading">Date Due</td>
         <td class="item">
            <input type="text" name="date_due" value="<%=dateDueString%>" size="50">
         </td>
      </tr>
      <%if((!"add".equals(command)) && (!"savenew".equals(command))){%>
      <tr>
         <td class="heading">Date In</td>
         <td class="item">
            <input type="text" name="date_in" value="<%=dateInString%>" size="50">
         </td>
      </tr>
      <%}%>


      <tr>
         <td colspan="2" class="item" align="center">
            <table cellspacing="2" cellPadding="2" width="619" border="0">
            <tr>
               <td align="center">
                  <%if(("add".equals(command)) || ("savenew".equals(command))){%>
                  <input type="button" value="Save" class="add" onclick="doSave(this, 'savenew')">
                  <%}else{%>
                  <input type="button" value="Save" class="add" onclick="doSave(this, 'save')">
                  <%}%>
               </td>
               <td align="center">
                  <input type="button" value="Cancel" class="add" onclick="doCancel(this)">
               </td>
            </tr>
            </table>
         </td>
      </tr>
      </table>
   </td>
</tr>


</table>
</form>
</body>
</html>

<%
// Close connection and throw exceptions
   connection.close();
}
catch(Exception exception)
{
throw exception;
}
%>
